@@ -628,10 +628,9 @@ FitMod <- function(formula, data, ..., subset, na.action=na.pass, fitfn=NULL){
     fun <- Tobit
 
   } else if(fitfn == "zeroinfl"){
-    # if (!requireNamespace("pscl", quietly = TRUE))
-    #   stop("package 'pscl' must be installed")
-    # fun <- get("zeroinfl", asNamespace("pscl"), inherits = FALSE)
-    fun <- zeroinfl
+    if (!requireNamespace("pscl", quietly = TRUE))
+      stop("package 'pscl' must be installed")
+    fun <- get("zeroinfl", asNamespace("pscl"), inherits = FALSE)
 
   } else if(fitfn == "multinom"){
     if (!requireNamespace("nnet", quietly = TRUE))
@@ -814,6 +813,7 @@ drop1.FitMod <- function(object, ...){
 }
 
 
+
 print.FitMod <- function(x, ...){
   if(inherits(x, "multinom"))
     .print.multinom(x, ...)
@@ -855,6 +855,21 @@ plot.FitMod <- function(x, ...){
   }
 }
 
+as.FitMod <- function(x){
+  structure(x, class=c("FitMod", class(x)))
+}
+
+
+update.FitMod <- function(object, ...){
+  # update kills the model class, so restore here
+  oclass <- class(object)
+  class(object) <- class(object)[class(object) != "FitMod"]
+  res <- update(object, ...)
+  class(res) <- oclass
+  return (res)
+}
+
+
 
 
 Response <- function(x, ...){
